Class: Aws::Route53RecoveryReadiness::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53RecoveryReadiness::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53recoveryreadiness/client.rb,
sig/client.rbs
Overview
An API client for Route53RecoveryReadiness. To construct a client, you need to configure a :region and :credentials.
client = Aws::Route53RecoveryReadiness::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateCellResponseSuccess, _CreateCrossAccountAuthorizationResponseSuccess, _CreateReadinessCheckResponseSuccess, _CreateRecoveryGroupResponseSuccess, _CreateResourceSetResponseSuccess, _DeleteCrossAccountAuthorizationResponseSuccess, _GetArchitectureRecommendationsResponseSuccess, _GetCellReadinessSummaryResponseSuccess, _GetCellResponseSuccess, _GetReadinessCheckResourceStatusResponseSuccess, _GetReadinessCheckResponseSuccess, _GetReadinessCheckStatusResponseSuccess, _GetRecoveryGroupReadinessSummaryResponseSuccess, _GetRecoveryGroupResponseSuccess, _GetResourceSetResponseSuccess, _ListCellsResponseSuccess, _ListCrossAccountAuthorizationsResponseSuccess, _ListReadinessChecksResponseSuccess, _ListRecoveryGroupsResponseSuccess, _ListResourceSetsResponseSuccess, _ListRulesResponseSuccess, _ListTagsForResourcesResponseSuccess, _TagResourceResponseSuccess, _UpdateCellResponseSuccess, _UpdateReadinessCheckResponseSuccess, _UpdateRecoveryGroupResponseSuccess, _UpdateResourceSetResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cell(params = {}) ⇒ Types::CreateCellResponse
Creates a cell in an account.
-
#create_cross_account_authorization(params = {}) ⇒ Types::CreateCrossAccountAuthorizationResponse
Creates a cross-account readiness authorization.
-
#create_readiness_check(params = {}) ⇒ Types::CreateReadinessCheckResponse
Creates a readiness check in an account.
-
#create_recovery_group(params = {}) ⇒ Types::CreateRecoveryGroupResponse
Creates a recovery group in an account.
-
#create_resource_set(params = {}) ⇒ Types::CreateResourceSetResponse
Creates a resource set.
-
#delete_cell(params = {}) ⇒ Struct
Delete a cell.
-
#delete_cross_account_authorization(params = {}) ⇒ Struct
Deletes cross account readiness authorization.
-
#delete_readiness_check(params = {}) ⇒ Struct
Deletes a readiness check.
-
#delete_recovery_group(params = {}) ⇒ Struct
Deletes a recovery group.
-
#delete_resource_set(params = {}) ⇒ Struct
Deletes a resource set.
-
#get_architecture_recommendations(params = {}) ⇒ Types::GetArchitectureRecommendationsResponse
Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group.
-
#get_cell(params = {}) ⇒ Types::GetCellResponse
Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
-
#get_cell_readiness_summary(params = {}) ⇒ Types::GetCellReadinessSummaryResponse
Gets readiness for a cell.
-
#get_readiness_check(params = {}) ⇒ Types::GetReadinessCheckResponse
Gets details about a readiness check.
-
#get_readiness_check_resource_status(params = {}) ⇒ Types::GetReadinessCheckResourceStatusResponse
Gets individual readiness status for a readiness check.
-
#get_readiness_check_status(params = {}) ⇒ Types::GetReadinessCheckStatusResponse
Gets the readiness status for an individual readiness check.
-
#get_recovery_group(params = {}) ⇒ Types::GetRecoveryGroupResponse
Gets details about a recovery group, including a list of the cells that are included in it.
-
#get_recovery_group_readiness_summary(params = {}) ⇒ Types::GetRecoveryGroupReadinessSummaryResponse
Displays a summary of information about a recovery group's readiness status.
-
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Displays the details about a resource set, including a list of the resources in the set.
-
#list_cells(params = {}) ⇒ Types::ListCellsResponse
Lists the cells for an account.
-
#list_cross_account_authorizations(params = {}) ⇒ Types::ListCrossAccountAuthorizationsResponse
Lists the cross-account readiness authorizations that are in place for an account.
-
#list_readiness_checks(params = {}) ⇒ Types::ListReadinessChecksResponse
Lists the readiness checks for an account.
-
#list_recovery_groups(params = {}) ⇒ Types::ListRecoveryGroupsResponse
Lists the recovery groups in an account.
-
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Lists the resource sets in an account.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists all readiness rules, or lists the readiness rules for a specific resource type.
-
#list_tags_for_resources(params = {}) ⇒ Types::ListTagsForResourcesResponse
Lists the tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_cell(params = {}) ⇒ Types::UpdateCellResponse
Updates a cell to replace the list of nested cells with a new list of nested cells.
-
#update_readiness_check(params = {}) ⇒ Types::UpdateReadinessCheckResponse
Updates a readiness check.
-
#update_recovery_group(params = {}) ⇒ Types::UpdateRecoveryGroupResponse
Updates a recovery group.
-
#update_resource_set(params = {}) ⇒ Types::UpdateResourceSetResponse
Updates a resource set.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1767 1768 1769 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1767 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1770 1771 1772 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1770 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1740 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53RecoveryReadiness') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53recoveryreadiness' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cell(params = {}) ⇒ Types::CreateCellResponse
Creates a cell in an account.
90 |
# File 'sig/client.rbs', line 90
def create_cell: (
|
#create_cross_account_authorization(params = {}) ⇒ Types::CreateCrossAccountAuthorizationResponse
Creates a cross-account readiness authorization. This lets you authorize another account to work with Route 53 Application Recovery Controller, for example, to check the readiness status of resources in a separate account.
102 |
# File 'sig/client.rbs', line 102
def create_cross_account_authorization: (
|
#create_readiness_check(params = {}) ⇒ Types::CreateReadinessCheckResponse
Creates a readiness check in an account. A readiness check monitors a resource set in your application, such as a set of Amazon Aurora instances, that Application Recovery Controller is auditing recovery readiness for. The audits run once every minute on every resource that's associated with a readiness check.
115 |
# File 'sig/client.rbs', line 115
def create_readiness_check: (
|
#create_recovery_group(params = {}) ⇒ Types::CreateRecoveryGroupResponse
Creates a recovery group in an account. A recovery group corresponds to an application and includes a list of the cells that make up the application.
130 |
# File 'sig/client.rbs', line 130
def create_recovery_group: (
|
#create_resource_set(params = {}) ⇒ Types::CreateResourceSetResponse
Creates a resource set. A resource set is a set of resources of one type that span multiple cells. You can associate a resource set with a readiness check to monitor the resources for failover readiness.
146 |
# File 'sig/client.rbs', line 146
def create_resource_set: (
|
#delete_cell(params = {}) ⇒ Struct
Delete a cell. When successful, the response code is 204, with no response body.
157 |
# File 'sig/client.rbs', line 157
def delete_cell: (
|
#delete_cross_account_authorization(params = {}) ⇒ Struct
Deletes cross account readiness authorization.
166 |
# File 'sig/client.rbs', line 166
def delete_cross_account_authorization: (
|
#delete_readiness_check(params = {}) ⇒ Struct
Deletes a readiness check.
172 |
# File 'sig/client.rbs', line 172
def delete_readiness_check: (
|
#delete_recovery_group(params = {}) ⇒ Struct
Deletes a recovery group.
178 |
# File 'sig/client.rbs', line 178
def delete_recovery_group: (
|
#delete_resource_set(params = {}) ⇒ Struct
Deletes a resource set.
184 |
# File 'sig/client.rbs', line 184
def delete_resource_set: (
|
#get_architecture_recommendations(params = {}) ⇒ Types::GetArchitectureRecommendationsResponse
Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group.
196 |
# File 'sig/client.rbs', line 196
def get_architecture_recommendations: (
|
#get_cell(params = {}) ⇒ Types::GetCellResponse
Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
212 |
# File 'sig/client.rbs', line 212
def get_cell: (
|
#get_cell_readiness_summary(params = {}) ⇒ Types::GetCellReadinessSummaryResponse
Gets readiness for a cell. Aggregates the readiness of all the resources that are associated with the cell into a single value.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
224 |
# File 'sig/client.rbs', line 224
def get_cell_readiness_summary: (
|
#get_readiness_check(params = {}) ⇒ Types::GetReadinessCheckResponse
Gets details about a readiness check.
239 |
# File 'sig/client.rbs', line 239
def get_readiness_check: (
|
#get_readiness_check_resource_status(params = {}) ⇒ Types::GetReadinessCheckResourceStatusResponse
Gets individual readiness status for a readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in the recovery group, use GetRecoveryGroupReadinessSummary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
251 |
# File 'sig/client.rbs', line 251
def get_readiness_check_resource_status: (
|
#get_readiness_check_status(params = {}) ⇒ Types::GetReadinessCheckStatusResponse
Gets the readiness status for an individual readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in a recovery group, use GetRecoveryGroupReadinessSummary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
267 |
# File 'sig/client.rbs', line 267
def get_readiness_check_status: (
|
#get_recovery_group(params = {}) ⇒ Types::GetRecoveryGroupResponse
Gets details about a recovery group, including a list of the cells that are included in it.
282 |
# File 'sig/client.rbs', line 282
def get_recovery_group: (
|
#get_recovery_group_readiness_summary(params = {}) ⇒ Types::GetRecoveryGroupReadinessSummaryResponse
Displays a summary of information about a recovery group's readiness status. Includes the readiness checks for resources in the recovery group and the readiness status of each one.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
294 |
# File 'sig/client.rbs', line 294
def get_recovery_group_readiness_summary: (
|
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Displays the details about a resource set, including a list of the resources in the set.
310 |
# File 'sig/client.rbs', line 310
def get_resource_set: (
|
#list_cells(params = {}) ⇒ Types::ListCellsResponse
Lists the cells for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
321 |
# File 'sig/client.rbs', line 321
def list_cells: (
|
#list_cross_account_authorizations(params = {}) ⇒ Types::ListCrossAccountAuthorizationsResponse
Lists the cross-account readiness authorizations that are in place for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
333 |
# File 'sig/client.rbs', line 333
def list_cross_account_authorizations: (
|
#list_readiness_checks(params = {}) ⇒ Types::ListReadinessChecksResponse
Lists the readiness checks for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
345 |
# File 'sig/client.rbs', line 345
def list_readiness_checks: (
|
#list_recovery_groups(params = {}) ⇒ Types::ListRecoveryGroupsResponse
Lists the recovery groups in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
357 |
# File 'sig/client.rbs', line 357
def list_recovery_groups: (
|
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Lists the resource sets in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
369 |
# File 'sig/client.rbs', line 369
def list_resource_sets: (
|
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists all readiness rules, or lists the readiness rules for a specific resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
381 |
# File 'sig/client.rbs', line 381
def list_rules: (
|
#list_tags_for_resources(params = {}) ⇒ Types::ListTagsForResourcesResponse
Lists the tags for a resource.
393 |
# File 'sig/client.rbs', line 393
def list_tags_for_resources: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
402 |
# File 'sig/client.rbs', line 402
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
409 |
# File 'sig/client.rbs', line 409
def untag_resource: (
|
#update_cell(params = {}) ⇒ Types::UpdateCellResponse
Updates a cell to replace the list of nested cells with a new list of nested cells.
424 |
# File 'sig/client.rbs', line 424
def update_cell: (
|
#update_readiness_check(params = {}) ⇒ Types::UpdateReadinessCheckResponse
Updates a readiness check.
438 |
# File 'sig/client.rbs', line 438
def update_readiness_check: (
|
#update_recovery_group(params = {}) ⇒ Types::UpdateRecoveryGroupResponse
Updates a recovery group.
452 |
# File 'sig/client.rbs', line 452
def update_recovery_group: (
|
#update_resource_set(params = {}) ⇒ Types::UpdateResourceSetResponse
Updates a resource set.
467 |
# File 'sig/client.rbs', line 467
def update_resource_set: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1760 1761 1762 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1760 def waiter_names [] end |