Class: Aws::Route53RecoveryReadiness::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53RecoveryReadiness::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53recoveryreadiness/client.rb
Overview
An API client for Route53RecoveryReadiness. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53RecoveryReadiness::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cell(params = {}) ⇒ Types::CreateCellResponse
Creates a cell in an account.
-
#create_cross_account_authorization(params = {}) ⇒ Types::CreateCrossAccountAuthorizationResponse
Creates a cross-account readiness authorization.
-
#create_readiness_check(params = {}) ⇒ Types::CreateReadinessCheckResponse
Creates a readiness check in an account.
-
#create_recovery_group(params = {}) ⇒ Types::CreateRecoveryGroupResponse
Creates a recovery group in an account.
-
#create_resource_set(params = {}) ⇒ Types::CreateResourceSetResponse
Creates a resource set.
-
#delete_cell(params = {}) ⇒ Struct
Delete a cell.
-
#delete_cross_account_authorization(params = {}) ⇒ Struct
Deletes cross account readiness authorization.
-
#delete_readiness_check(params = {}) ⇒ Struct
Deletes a readiness check.
-
#delete_recovery_group(params = {}) ⇒ Struct
Deletes a recovery group.
-
#delete_resource_set(params = {}) ⇒ Struct
Deletes a resource set.
-
#get_architecture_recommendations(params = {}) ⇒ Types::GetArchitectureRecommendationsResponse
Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group.
-
#get_cell(params = {}) ⇒ Types::GetCellResponse
Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
-
#get_cell_readiness_summary(params = {}) ⇒ Types::GetCellReadinessSummaryResponse
Gets readiness for a cell.
-
#get_readiness_check(params = {}) ⇒ Types::GetReadinessCheckResponse
Gets details about a readiness check.
-
#get_readiness_check_resource_status(params = {}) ⇒ Types::GetReadinessCheckResourceStatusResponse
Gets individual readiness status for a readiness check.
-
#get_readiness_check_status(params = {}) ⇒ Types::GetReadinessCheckStatusResponse
Gets the readiness status for an individual readiness check.
-
#get_recovery_group(params = {}) ⇒ Types::GetRecoveryGroupResponse
Gets details about a recovery group, including a list of the cells that are included in it.
-
#get_recovery_group_readiness_summary(params = {}) ⇒ Types::GetRecoveryGroupReadinessSummaryResponse
Displays a summary of information about a recovery group’s readiness status.
-
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Displays the details about a resource set, including a list of the resources in the set.
-
#list_cells(params = {}) ⇒ Types::ListCellsResponse
Lists the cells for an account.
-
#list_cross_account_authorizations(params = {}) ⇒ Types::ListCrossAccountAuthorizationsResponse
Lists the cross-account readiness authorizations that are in place for an account.
-
#list_readiness_checks(params = {}) ⇒ Types::ListReadinessChecksResponse
Lists the readiness checks for an account.
-
#list_recovery_groups(params = {}) ⇒ Types::ListRecoveryGroupsResponse
Lists the recovery groups in an account.
-
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Lists the resource sets in an account.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists all readiness rules, or lists the readiness rules for a specific resource type.
-
#list_tags_for_resources(params = {}) ⇒ Types::ListTagsForResourcesResponse
Lists the tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_cell(params = {}) ⇒ Types::UpdateCellResponse
Updates a cell to replace the list of nested cells with a new list of nested cells.
-
#update_readiness_check(params = {}) ⇒ Types::UpdateReadinessCheckResponse
Updates a readiness check.
-
#update_recovery_group(params = {}) ⇒ Types::UpdateRecoveryGroupResponse
Updates a recovery group.
-
#update_resource_set(params = {}) ⇒ Types::UpdateResourceSetResponse
Updates a resource set.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1769 1770 1771 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1769 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1772 1773 1774 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1772 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1742 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53RecoveryReadiness') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53recoveryreadiness' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cell(params = {}) ⇒ Types::CreateCellResponse
Creates a cell in an account.
521 522 523 524 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 521 def create_cell(params = {}, = {}) req = build_request(:create_cell, params) req.send_request() end |
#create_cross_account_authorization(params = {}) ⇒ Types::CreateCrossAccountAuthorizationResponse
Creates a cross-account readiness authorization. This lets you authorize another account to work with Route 53 Application Recovery Controller, for example, to check the readiness status of resources in a separate account.
552 553 554 555 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 552 def (params = {}, = {}) req = build_request(:create_cross_account_authorization, params) req.send_request() end |
#create_readiness_check(params = {}) ⇒ Types::CreateReadinessCheckResponse
Creates a readiness check in an account. A readiness check monitors a resource set in your application, such as a set of Amazon Aurora instances, that Application Recovery Controller is auditing recovery readiness for. The audits run once every minute on every resource that’s associated with a readiness check.
599 600 601 602 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 599 def create_readiness_check(params = {}, = {}) req = build_request(:create_readiness_check, params) req.send_request() end |
#create_recovery_group(params = {}) ⇒ Types::CreateRecoveryGroupResponse
Creates a recovery group in an account. A recovery group corresponds to an application and includes a list of the cells that make up the application.
645 646 647 648 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 645 def create_recovery_group(params = {}, = {}) req = build_request(:create_recovery_group, params) req.send_request() end |
#create_resource_set(params = {}) ⇒ Types::CreateResourceSetResponse
Creates a resource set. A resource set is a set of resources of one type that span multiple cells. You can associate a resource set with a readiness check to monitor the resources for failover readiness.
727 728 729 730 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 727 def create_resource_set(params = {}, = {}) req = build_request(:create_resource_set, params) req.send_request() end |
#delete_cell(params = {}) ⇒ Struct
Delete a cell. When successful, the response code is 204, with no response body.
749 750 751 752 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 749 def delete_cell(params = {}, = {}) req = build_request(:delete_cell, params) req.send_request() end |
#delete_cross_account_authorization(params = {}) ⇒ Struct
Deletes cross account readiness authorization.
770 771 772 773 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 770 def (params = {}, = {}) req = build_request(:delete_cross_account_authorization, params) req.send_request() end |
#delete_readiness_check(params = {}) ⇒ Struct
Deletes a readiness check.
791 792 793 794 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 791 def delete_readiness_check(params = {}, = {}) req = build_request(:delete_readiness_check, params) req.send_request() end |
#delete_recovery_group(params = {}) ⇒ Struct
Deletes a recovery group.
812 813 814 815 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 812 def delete_recovery_group(params = {}, = {}) req = build_request(:delete_recovery_group, params) req.send_request() end |
#delete_resource_set(params = {}) ⇒ Struct
Deletes a resource set.
833 834 835 836 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 833 def delete_resource_set(params = {}, = {}) req = build_request(:delete_resource_set, params) req.send_request() end |
#get_architecture_recommendations(params = {}) ⇒ Types::GetArchitectureRecommendationsResponse
Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group.
872 873 874 875 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 872 def get_architecture_recommendations(params = {}, = {}) req = build_request(:get_architecture_recommendations, params) req.send_request() end |
#get_cell(params = {}) ⇒ Types::GetCellResponse
Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs.
912 913 914 915 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 912 def get_cell(params = {}, = {}) req = build_request(:get_cell, params) req.send_request() end |
#get_cell_readiness_summary(params = {}) ⇒ Types::GetCellReadinessSummaryResponse
Gets readiness for a cell. Aggregates the readiness of all the resources that are associated with the cell into a single value.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
954 955 956 957 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 954 def get_cell_readiness_summary(params = {}, = {}) req = build_request(:get_cell_readiness_summary, params) req.send_request() end |
#get_readiness_check(params = {}) ⇒ Types::GetReadinessCheckResponse
Gets details about a readiness check.
988 989 990 991 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 988 def get_readiness_check(params = {}, = {}) req = build_request(:get_readiness_check, params) req.send_request() end |
#get_readiness_check_resource_status(params = {}) ⇒ Types::GetReadinessCheckResourceStatusResponse
Gets individual readiness status for a readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in the recovery group, use GetRecoveryGroupReadinessSummary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1038 1039 1040 1041 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1038 def get_readiness_check_resource_status(params = {}, = {}) req = build_request(:get_readiness_check_resource_status, params) req.send_request() end |
#get_readiness_check_status(params = {}) ⇒ Types::GetReadinessCheckStatusResponse
Gets the readiness status for an individual readiness check. To see the overall readiness status for a recovery group, that considers the readiness status for all the readiness checks in a recovery group, use GetRecoveryGroupReadinessSummary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1087 1088 1089 1090 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1087 def get_readiness_check_status(params = {}, = {}) req = build_request(:get_readiness_check_status, params) req.send_request() end |
#get_recovery_group(params = {}) ⇒ Types::GetRecoveryGroupResponse
Gets details about a recovery group, including a list of the cells that are included in it.
1123 1124 1125 1126 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1123 def get_recovery_group(params = {}, = {}) req = build_request(:get_recovery_group, params) req.send_request() end |
#get_recovery_group_readiness_summary(params = {}) ⇒ Types::GetRecoveryGroupReadinessSummaryResponse
Displays a summary of information about a recovery group’s readiness status. Includes the readiness checks for resources in the recovery group and the readiness status of each one.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1166 1167 1168 1169 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1166 def get_recovery_group_readiness_summary(params = {}, = {}) req = build_request(:get_recovery_group_readiness_summary, params) req.send_request() end |
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Displays the details about a resource set, including a list of the resources in the set.
1214 1215 1216 1217 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1214 def get_resource_set(params = {}, = {}) req = build_request(:get_resource_set, params) req.send_request() end |
#list_cells(params = {}) ⇒ Types::ListCellsResponse
Lists the cells for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1256 def list_cells(params = {}, = {}) req = build_request(:list_cells, params) req.send_request() end |
#list_cross_account_authorizations(params = {}) ⇒ Types::ListCrossAccountAuthorizationsResponse
Lists the cross-account readiness authorizations that are in place for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1292 1293 1294 1295 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1292 def (params = {}, = {}) req = build_request(:list_cross_account_authorizations, params) req.send_request() end |
#list_readiness_checks(params = {}) ⇒ Types::ListReadinessChecksResponse
Lists the readiness checks for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1331 1332 1333 1334 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1331 def list_readiness_checks(params = {}, = {}) req = build_request(:list_readiness_checks, params) req.send_request() end |
#list_recovery_groups(params = {}) ⇒ Types::ListRecoveryGroupsResponse
Lists the recovery groups in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1371 1372 1373 1374 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1371 def list_recovery_groups(params = {}, = {}) req = build_request(:list_recovery_groups, params) req.send_request() end |
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Lists the resource sets in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1422 1423 1424 1425 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1422 def list_resource_sets(params = {}, = {}) req = build_request(:list_resource_sets, params) req.send_request() end |
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists all readiness rules, or lists the readiness rules for a specific resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1463 1464 1465 1466 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1463 def list_rules(params = {}, = {}) req = build_request(:list_rules, params) req.send_request() end |
#list_tags_for_resources(params = {}) ⇒ Types::ListTagsForResourcesResponse
Lists the tags for a resource.
1491 1492 1493 1494 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1491 def (params = {}, = {}) req = build_request(:list_tags_for_resources, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
1518 1519 1520 1521 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1518 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
1542 1543 1544 1545 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1542 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cell(params = {}) ⇒ Types::UpdateCellResponse
Updates a cell to replace the list of nested cells with a new list of nested cells.
1584 1585 1586 1587 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1584 def update_cell(params = {}, = {}) req = build_request(:update_cell, params) req.send_request() end |
#update_readiness_check(params = {}) ⇒ Types::UpdateReadinessCheckResponse
Updates a readiness check.
1621 1622 1623 1624 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1621 def update_readiness_check(params = {}, = {}) req = build_request(:update_readiness_check, params) req.send_request() end |
#update_recovery_group(params = {}) ⇒ Types::UpdateRecoveryGroupResponse
Updates a recovery group.
1659 1660 1661 1662 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1659 def update_recovery_group(params = {}, = {}) req = build_request(:update_recovery_group, params) req.send_request() end |
#update_resource_set(params = {}) ⇒ Types::UpdateResourceSetResponse
Updates a resource set.
1733 1734 1735 1736 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1733 def update_resource_set(params = {}, = {}) req = build_request(:update_resource_set, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1762 1763 1764 |
# File 'lib/aws-sdk-route53recoveryreadiness/client.rb', line 1762 def waiter_names [] end |